import { ref, unref, computed, onMounted } from 'vue'
import { isBoolean } from '@/utils/is'

export function useDataSource(propsRef, { getPaginationInfo, setPagination, setLoading, tableData }, emit) {
  const dataSourceRef = ref([])

  async function fetch(opt) {
    try {
    //   setLoading(true)
      const { request, pagination } = unref(propsRef)
      /* 无接口请求中断 */
      if (!request) return
      /* 获取分页信息 */
      const paginationSetting = propsRef.paginationSetting
      const pageField = paginationSetting.pageField
      const sizeField = paginationSetting.sizeField
      const totalField = paginationSetting.totalField
      const listField = paginationSetting.listField

      let pageParams = {}
      const { page = 1, pageSize = 10 } = unref(getPaginationInfo)
      if ((isBoolean(pagination) && !pagination) || isBoolean(getPaginationInfo)) {
        pageParams = {}
      } else {
        pageParams[pageField] = (opt && opt[pageField]) || page
        pageParams[sizeField] = pageSize
      }

      const params = {
        ...pageParams
      }
      const res = await request(params)
      console.log('res', res)
      const resultTotal = res[totalField] || 0
      const currentPage = res[pageField]

      // // 如果数据异常，需获取正确的页码再次执行
      // if (resultTotal) {
      //   if (page > resultTotal) {
      //     setPagination({
      //       [pageField]: resultTotal
      //     })
      //     fetch(opt)
      //   }
      // }
      const resultInfo = res[listField] ? res[listField] : []
      dataSourceRef.value = resultInfo
      setPagination({
        [pageField]: currentPage,
        [totalField]: resultTotal
      })
      // if (opt && opt[pageField]) {
      //   setPagination({
      //     [pageField]: opt[pageField] || 1
      //   })
      // }
      emit('fetch-success', {
        items: unref(resultInfo),
        resultTotal
      })
    } catch (error) {
      console.error(error)
      // emit('fetch-error', error)
      // dataSourceRef.value = []
    } finally {
      setLoading(false)
    }
  }

  const getDataSourceRef = computed(() => {
    const dataSource = unref(dataSourceRef)
    if (!dataSource || dataSource.length === 0) {
      return unref(dataSourceRef)
    }
    return unref(dataSourceRef)
  })

  function getDataSource() {
    console.log(getDataSourceRef.value)
    return getDataSourceRef.value
  }

  function setTableData(values) {
    dataSourceRef.value = values
  }

  onMounted(() => {
    setTimeout(() => {
      fetch()
    }, 15)
  })

  return {
    fetch,
    getDataSourceRef,
    getDataSource,
    setTableData
  }
}
